# If you use C shell derivatives (eg. tcsh), source this file to set up your
# environment to use lscsoft software.

# turn on verbose (with -v option) to see what's happening to your system
@ myverbosity = 0

# only print messages when verbose option is on
alias userenv_report 'if ( $myverbosity == 1 ) echo \!*'

# check for the verbose option
@ n = 1
while ($n <= $#argv)
   if ("$argv[$n]" == "-v") then
      @ n++
      @ myverbosity = 1
   endif
   @ n++
end

# If the .nolscsoft or .noall file exists, do not setup anything
if ( -f ${HOME}/.noanything ) then
    userenv_report "Automatic setup of lscsoft *disabled* by ~/.noanything"
    exit
endif

# for those whose english dialect respects double negatives ;)
if ( -f ${HOME}/.nonothing ) then
    userenv_report "Automatic setup of lscsoft *disabled* by ~/.nonothing"
    exit
endif
    
# Just turn off all of lscsoft
if ( -f ${HOME}/.nolscsoft ) then
    userenv_report "Automatic setup of lscsoft *disabled* by ~/.nolscsoft"
    exit
endif


setenv LSCSOFT_PREFIX /opt/lscsoft

## Now begin filters based on individual packages

setenv PKGLIST_A "libmetaio libframe"

# Handle package list A
setenv PKGSETUP_A ""
foreach name ( $PKGLIST_A )
    if ( -f ${HOME}/.nolscsoft-$name ) then
        if ( ! ${?NOSETUP_A} ) then
            setenv NOSETUP_A ""
        endif
        setenv NOSETUP_A "$NOSETUP_A $name"
    else
        setenv PKGSETUP_A "$PKGSETUP_A $name"
    endif
end

# Handle LAL package
if ( -f ${HOME}/.nolscsoft-lal ) then
    setenv NOSETUP_LAL "lal"
endif



if ( ! ${?PATH} ) setenv PATH ""
if ( ! ${?PKG_CONFIG_PATH} ) setenv PKG_CONFIG_PATH ""
if ( ! ${?LD_LIBRARY_PATH} ) setenv LD_LIBRARY_PATH ""
if ( ! ${?MANPATH} ) setenv MANPATH ""

### Now actually perform the environment setup.
# print header
userenv_report "+++++++++++++++++++++++ lscsoft environment +++++++++++++++++++++++"
userenv_report "  Package	Vers.	Path"
userenv_report " "

# Package set A setup
foreach directory ( $PKGSETUP_A )
	if ( -d "${LSCSOFT_PREFIX}/${directory}" ) then
		setenv PATH ${LSCSOFT_PREFIX}/${directory}/bin:${PATH}
		setenv PKG_CONFIG_PATH ${LSCSOFT_PREFIX}/${directory}/lib/pkgconfig:${PKG_CONFIG_PATH}
		setenv LD_LIBRARY_PATH ${LSCSOFT_PREFIX}/${directory}/lib:${LD_LIBRARY_PATH}
		setenv MANPATH ${LSCSOFT_PREFIX}/${directory}/man:${MANPATH}
        
        setenv ver " "
        setenv ver `grep Version ${LSCSOFT_PREFIX}/${directory}/lib/pkgconfig/${directory}.pc| awk '{print $NF}'`
        userenv_report "+ $directory	$ver	${LSCSOFT_PREFIX}/${directory}"
        userenv_report " "
		
	endif
end


# Package A disability report
if ( ${?NOSETUP_A} ) then

    foreach name ( $NOSETUP_A ) 
        userenv_report "- $name	*Disabled* by ~/.nolscsoft-$name"
        userenv_report " "
    end
    
endif


# LAL package setup
if ( ! ${?NOSETUP_LAL} ) then
    
    if ( -d "${LSCSOFT_PREFIX}/lal" ) then 
        setenv LAL_LOCATION ${LSCSOFT_PREFIX}/lal
        source ${LAL_LOCATION}/etc/lal-user-env.csh
        setenv ver " "
        setenv ver `lal-version | grep 'LAL Version:' | awk '{print $NF}'`
        userenv_report "+ lal		$ver	${LSCSOFT_PREFIX}/lal"
    endif
    
else
	userenv_report "- lal		*Disabled* by ~/.nolscsoft-lal"
    
endif


# print footer
userenv_report " "
userenv_report "++ Note: some packages might be overridden by your own profile. ++"

# unset appropriate vars free()!
unsetenv PKGLIST_A
unsetenv NOSETUP_A
unsetenv NOSETUP_LAL
unsetenv ver
unsetenv name
unsetenv directory
### Fin
